import { useState } from 'react';

import s from './TimerControl.module.css';

interface ITimerControlProps {
  flag: string;
  setRefreshMs: React.Dispatch<React.SetStateAction<number>>;
  setHours: React.Dispatch<React.SetStateAction<number>>;
  setMinutes: React.Dispatch<React.SetStateAction<number>>;
  setSeconds: React.Dispatch<React.SetStateAction<number>>;
}

const TimerControl = ({
  flag,
  setRefreshMs,
  setHours,
  setMinutes,
  setSeconds,
}: ITimerControlProps) => {
  const handleTimeInput = (e: React.ChangeEvent<HTMLInputElement>) => {
    const name = e.target.name;
    const value = Number(e.target.value);
    switch (name) {
      case 'refresh':
        setRefreshMs(value);
        break;
      case 'hours':
        setHours(value);
        break;
      case 'minutes':
        setMinutes(value);
        break;
      case 'seconds':
        setSeconds(value);
        break;
      default:
        break;
    }
  };

  const isProceed = flag === 'Pause';

  return (
    <div className={s.timerControlWrapper}>
      <input
        onChange={handleTimeInput}
        name="refresh"
        className={s.timerInput}
        type="number"
        placeholder="Refresh 1 equal 100ms"
        disabled={isProceed ? true : false}
      ></input>
      <input
        onChange={handleTimeInput}
        name="hours"
        className={s.timerInput}
        type="number"
        placeholder="Hours"
        disabled={isProceed ? true : false}
      ></input>
      <input
        onChange={handleTimeInput}
        name="minutes"
        className={s.timerInput}
        type="number"
        placeholder="Minutes"
        disabled={isProceed ? true : false}
      ></input>
      <input
        onChange={handleTimeInput}
        name="seconds"
        className={s.timerInput}
        type="number"
        placeholder="Seconds"
        disabled={isProceed ? true : false}
      ></input>
    </div>
  );
};

export default TimerControl;
